@@ -16,13 +16,24 @@ public class WorldStateJointsListener extends TCPListener {
       InputStream in=socket.getInputStream();
       while (true) {
         _data.timestamp=readInt(in);
-        for (int i=0; i<18; i++)
+				//System.out.println("time="+_data.timestamp);
+				int NumPIDJoints=readInt(in);
+				_data.positions=new float[NumPIDJoints];
+				_data.duties=new float[NumPIDJoints];
+				//System.out.println("pid="+NumPIDJoints);
+        for (int i=0; i<NumPIDJoints; i++)
           _data.positions[i]=readFloat(in);
-        for (int i=0; i<6; i++)
+				int NumSensors=readInt(in);
+				_data.sensors=new float[NumSensors];
+				//System.out.println("sensor="+NumSensors);
+        for (int i=0; i<NumSensors; i++)
           _data.sensors[i]=readFloat(in);
-        for (int i=0; i<8; i++)
+				int NumButtons=readInt(in);
+				_data.buttons=new float[NumButtons];
+				//System.out.println("button="+NumButtons);
+        for (int i=0; i<NumButtons; i++)
           _data.buttons[i]=readFloat(in);
-        for (int i=0; i<18; i++)
+        for (int i=0; i<NumPIDJoints; i++)
           _data.duties[i]=readFloat(in);
 
         synchronized(_outd) {
